Claude model prices (last updated May 13, 2026) Data set containing input and output prizes for all Claude's API models.
Source:R/data.R
claude_model_prizes.RdClaude model prices (last updated May 13, 2026) Data set containing input and output prizes for all Claude's API models.
Format
A data.frame containing 4 rows/models and 3 variables/columns
| model | character | indicating the specific GPT model |
| price_in_per_token | character | indicating the input prize per token |
| price_out_per_token | character | indicating the output prize per token |
References
Anthropic. Pricing. https://platform.claude.com/docs/en/about-claude/pricing