Get GROQ API key from R environment variable.
Arguments
- env_var
Character string indicating the name of the temporary R environment variable with the API key and the used AI model. Currently, the argument only takes
env_var = "GROQ_API_KEY". Seeset_api_key()to set/create this variable.
Details
get_api_key_groq() can be used after executing set_api_key() or by adding the
api key permanently to your R environment by using usethis::edit_r_environ().
Then write GROQ_API_KEY=[insert your api key here] and close the .Renviron window and restart R.
Note
Find your personal API key at https://console.groq.com/keys.