View source: R/save_functions.r
| save_dataframe_to_ris | R Documentation |
Writes a data.frame to a RIS file, one record per row. If the data frame was created
by read_ris_to_dataframe(), the original RIS tag order and tags are preserved where possible.
Otherwise, a standard RIS format is used.
save_dataframe_to_ris(df, file_path)
df |
data.frame. The data to write. |
file_path |
character. Path to the output RIS file. |
If a field value contains semicolons, it is split and written as multiple tag lines. The TY
(source type) field is written first for each record, followed by all other fields. Records are
terminated with ER - .
A character string indicating the file path where the RIS file was saved.
## Not run:
df <- read_ris_to_dataframe("data-raw/raw data/apa_psycinfo_test_data.ris")
save_dataframe_to_ris(df, "path/to/output.ris")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.