get_api_key_groq: Get GROQ API key from R environment variable.

View source: R/api_key_functions.R

get_api_key_groqR Documentation

Get GROQ API key from R environment variable.

Description

Get GROQ API key from R environment variable.

Usage

get_api_key_groq(env_var = "GROQ_API_KEY")

Arguments

env_var

Character string indicating the name of the temporary R environment variable with the API key and the used AI model. Currently, the argument only takes env_var = "GROQ_API_KEY". See set_api_key() to set/create this variable.

Details

get_api_key_groq() can be used after executing set_api_key() or by adding the api key permanently to your R environment by using usethis::edit_r_environ(). Then write ⁠GROQ_API_KEY=[insert your api key here]⁠ and close the .Renviron window and restart R.

Value

The specified API key (NOTE: Avoid exposing this in the console).

Note

Find your personal API key at https://console.groq.com/keys.

See Also

set_api_key.

Examples

## Not run: 
get_api_key_groq()

## End(Not run)

AIscreenR documentation built on April 13, 2026, 5:08 p.m.