View source: R/save_functions.r
| read_ris_to_dataframe | R Documentation |
Parses an RIS file into a data.frame, preserving the order of tags as they first appear in the file. Repeated tags within a record are collapsed into a single semicolon-separated string.
read_ris_to_dataframe(file_path)
file_path |
character. Path to the RIS file to read. |
A data.frame with one row per record and one column per encountered RIS tag, using descriptive column names. Columns are ordered by first appearance of the tag in the file. Repeated tag values are collapsed with "; ".
## Not run:
df <- read_ris_to_dataframe("data-raw/raw data/apa_psycinfo_test_data.ris")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.